@@ -68,8 +68,9 @@
 #'   }
 #' @param control.NNE List of control parameters for NNE algorithm:
 #'   \describe{
-#'     \item{\code{hidden.layers}}{Integer vector specifying layer sizes in fully-connected network (default: \code{c(12,12)}).}
+#'     \item{\code{hidden.layers}}{Integer vector specifying layer sizes in fully-connected network (default: \code{c(16,16)}).}
 #'     \item{\code{activation.function}}{Activation function (e.g., \code{"tanh"}, default: \code{"tanh"}).}
+#'     \item{\code{use.attention}}{Whether to enable the self-attention mechanism (i.e., transformer encoder) (default: \code{TRUE}).}
 #'     \item{\code{d.model}}{Dimensionality of transformer encoder embeddings (default: 8).}
 #'     \item{\code{nhead}}{Number of attention heads in transformer (default: 2).}
 #'     \item{\code{dim.feedforward}}{Dimensionality of transformer feedforward network (default: 16).}
@@ -369,8 +370,9 @@ LPA <- function(response,
   default_control.EM <- list(maxiter=2000, tol=1e-4)
   default_control.Mplus <- list(maxiter=2000, tol=1e-4, files.path = NULL, files.clean = TRUE)
   default_control.NNE <- list(
-    hidden.layers = c(12, 12),
+    hidden.layers = c(16, 16),
     activation.function = "tanh",
+    use.attention=TRUE,
     d.model = 8,
     nhead = 2,
     dim.feedforward = 16,
@@ -392,14 +394,13 @@ LPA <- function(response,
 
   merge_and_clean_control <- function(user_control, default_control) {
     if (is.null(user_control)) return(default_control)
-
-    merged_control <- modifyList(default_control, user_control)
-
-    merged_control <- merged_control[names(default_control)]
-
-    for (param_name in names(default_control)) {
-      if (is.null(merged_control[[param_name]])) {
-        merged_control[[param_name]] <- default_control[[param_name]]
+    valid_names <- intersect(names(user_control), names(default_control))
+    cleaned_user_control <- user_control[valid_names]
+    merged_control <- default_control
+    for (param_name in names(cleaned_user_control)) {
+      user_value <- cleaned_user_control[[param_name]]
+      if (!is.null(user_value)) {
+        merged_control[[param_name]] <- user_value
       }
     }
     return(merged_control)
@@ -428,6 +429,7 @@ LPA <- function(response,
                   vis=vis,
                   hidden_layers=control.NNE$hidden.layers,
                   activation_function=control.NNE$activation.function,
+                  use_attention=control.NNE$use.attention,
                   d_model=control.NNE$d.model,
                   nhead=control.NNE$nhead,
                   dim_feedforward=control.NNE$dim.feedforward,
